@@ -3,13 +3,18 @@
 use crate::imdb::error::Err;
 use crate::imdb::utils::tokens;
 use atoi::atoi;
+use serde::{Serialize, Serializer};
 use std::error::Error;
 use std::fmt;
 use std::hash::{Hash, Hasher};
 
-#[derive(Debug, Clone, Copy)]
+/// The ID corresponding to a title as u8 and usize
+#[derive(Debug, Clone, Copy, Serialize)]
 pub struct TitleId<'a> {
+  #[serde(serialize_with = "bytes_serializer", rename = "title_id")]
   bytes: &'a [u8],
+
+  #[serde(skip_serializing)]
   num: usize,
 }
 
@@ -28,14 +33,17 @@ impl Hash for TitleId<'_> {
 }
 
 impl<'a> TitleId<'a> {
+  /// Returns the title id as bytes
   pub(crate) fn as_bytes(&self) -> &'a [u8] {
     self.bytes
   }
 
+  /// Returns the title id as str
   pub(crate) fn as_str(&self) -> &'a str {
     unsafe { std::str::from_utf8_unchecked(self.bytes) }
   }
 
+  /// Returns the title id as usize
   pub(crate) fn as_usize(&self) -> usize {
     self.num
   }
@@ -61,3 +69,12 @@ impl fmt::Display for TitleId<'_> {
     write!(f, "{}", self.as_str())
   }
 }
+
+fn bytes_serializer<S>(bytes: &[u8], serializer: S) -> Result<S::Ok, S::Error>
+where
+  S: Serializer,
+{
+  let s = unsafe { std::str::from_utf8_unchecked(bytes) };
+
+  serializer.serialize_str(s)
+}
